Pre Survey
-----------------------------------------------------

Please answer the following questions.

==============

.. poll:: hparsons_lg_regex_presurvey_1
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    Generally I have felt secure about attempting computer programming problems.

.. poll:: hparsons_lg_regex_presurvey_2
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I am sure I could do advanced work in computer science.

.. poll:: hparsons_lg_regex_presurvey_3
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I am sure that I can learn programming.

.. poll:: hparsons_lg_regex_presurvey_4
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I think I could handle more difficult programming problems.

.. poll:: hparsons_lg_regex_presurvey_5
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I can get good grades in computer science.

.. poll:: hparsons_lg_regex_presurvey_6
    :option_1: Strongly disagree
    :option_2: Disagree
    :option_3: Neither agree nor disagree
    :option_4: Agree
    :option_5: Strongly agree
    :results: instructor

    I have a lot of self-confidence when it comes to programming.

For the next questions please select the answer that best
matches your familiarity and confidence
about the specified concept(s).

.. poll:: hparsons_lg_regex_presurvey_7
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Character sets, ranges, and sets (e.g. <code>[abc]</code>, <code>[a-c]</code>, and <code>\s</code>) in regex.

.. poll:: hparsons_lg_regex_presurvey_8
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Repetition (e.g. <code>{1, 3}</code>, or <code>+</code>) in regex.

.. poll:: hparsons_lg_regex_presurvey_9
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Grouping (e.g. <code>(ab)cd</code>) in regex.

.. poll:: hparsons_lg_regex_presurvey_10
    :option_1: I am unfamiliar with this concept
    :option_2: I know what it means, but have not used it in a program
    :option_3: I have used this concept in a program, but am not confident about my ability to use it
    :option_4: I am confident in my ability to use this concept in simple programs
    :option_5: I am confident in my ability to use this concept in complex programs
    :results: instructor

    Escaping special symbols (e.g. <code>\$</code>) in regex.

What to do next
============================
.. raw:: html

    <p>Click on the following link to complete a non-graded test on your knowledge about regex: <b><a id="hparsons_lg_session1_pretest"><font size="+2">Pre test</font></a></b></p>

.. raw:: html

    <script type="text/javascript" >

      window.onload = function() {

        a = document.getElementById("hparsons_lg_session1_pretest")
        a.href = "hparsons_lg_session1_pretest.html"

      };

    </script>
